Skip to main content

RA Fixture Generator

OS2mo/LoRa Flatfile Fixture Generator.

Usage

docker build . -t ra-fixture-generator

Which yields:

...
Successfully built ...
Successfully tagged ra-fixture-generator:latest

After which you can run:

docker run --rm ra-fixture-generator --help

Which yields:

Usage: fixture_generator.py [OPTIONS]

  Flatfile Fixture Generator.

  Used to generate flatfile fixture data (JSON) for OS2mo/LoRa.

Options:
  --name TEXT           Name of the root organization  [required]
  --indent INTEGER      Pass 'indent' to json serializer
  --lora-file FILENAME  Output Lora Flatfile  [required]
  --mo-file FILENAME    Output OS2mo Flatfile  [required]
  --help                Show this message and exit.

At this point two flat files can be generated with:

docker run --rm -v $PWD:/srv/ ra-fixture-generator \
    --name "Aarhus Kommune" --lora-file /srv/lora.json --mo-file /srv/mo.json

At which point two files lora.json and mo.json will be available in the current work-dir. These files can then be uploaded using the ra-flatfile-importer.

For instance using:

docker run -i --rm ra-flatfile-importer lora upload --mox-url http://MOXURL:8080 < lora.json
docker run -i --rm ra-flatfile-importer mo upload --mo-url http://MOURL:5000 < mo.json

Alternatively the two can be combined:

docker run -i --rm ra-fixture-generator \
    --name "Aarhus Kommune" --lora-file - --mo-file /dev/null | \
docker run -i --rm ra-flatfile-importer lora upload --mox-url http://MOXURL:8080

And similarily for MO:

docker run -i --rm ra-fixture-generator \
   --name "Aarhus Kommune" --lora-file /dev/null --mo-file - | \
docker run -i --rm ra-flatfile-importer mo upload --mo-url http://MOURL:5000

Versioning

This project uses Semantic Versioning with the following strategy:

  • MAJOR: Incompatible changes to existing data models
  • MINOR: Backwards compatible updates to existing data models OR new models added
  • PATCH: Backwards compatible bug fixes

License

  • This project: MPL-2.0
  • Dependencies:
    • pydantic: MIT

This project uses REUSE for licensing. All licenses can be found in the LICENSES folder of the project.

Metadata

Release files for ra-fixture-generator 0.2.0

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Source distribution (sdist)

Source distribution for ra-fixture-generator 0.2.0
File Size Uploaded
ra-fixture-generator-0.2.0.tar.gz 9.0 kB Details

Built distribution (wheel)

Table of built distributions (wheels) for ra-fixture-generator 0.2.0
File Interpreter ABI Platform
ra_fixture_generator-0.2.0-py3-none-any.whl Python 3 none any Details

Total release size: 23.7 kB

Release files / ra-fixture-generator-0.2.0.tar.gz

Download URL ra-fixture-generator-0.2.0.tar.gz
Size 9.0 kB
Tags Source
SHA-256 checksum
How to use checksums
f25ec2ca41dbe2704dc76905e82c08bc2a41f33d96e7798f52dbb465f9a108ed
BLAKE2b-256 checksum
How to use checksums
195b1b804e2e219300f4ceb810981a444eab033bb992bfa06b2a38bdf8d4ff7b
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via poetry/1.1.9 CPython/3.8.12 Linux/5.4.0-1049-gcp

Release files / ra_fixture_generator-0.2.0-py3-none-any.whl

Download URL ra_fixture_generator-0.2.0-py3-none-any.whl
Size 14.7 kB
Tags Python 3
SHA-256 checksum
How to use checksums
dd1e28e265b67f7f9498e5fa97bd175cea9264cf694e5614d4a991f974796d4f
BLAKE2b-256 checksum
How to use checksums
4fe75a9c28c04c8414bcc81db10ddceca3e11a86f2a2f0ed0d52152a89fe91aa
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via poetry/1.1.9 CPython/3.8.12 Linux/5.4.0-1049-gcp

Release history Release notifications | RSS feed

This release

0.2.0 This release

2 release files

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page